package cn.com.infosec.jce.spec;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.CryptoProObjectIdentifiers;
import cn.com.infosec.asn1.cryptopro.GOST3410NamedParameters;
import cn.com.infosec.asn1.cryptopro.GOST3410ParamSetParameters;
import cn.com.infosec.asn1.cryptopro.GOST3410PublicKeyAlgParameters;
import cn.com.infosec.jce.interfaces.GOST3410Params;
import java.math.BigInteger;
import java.security.spec.AlgorithmParameterSpec;

public class GOST3410ParameterSpec implements AlgorithmParameterSpec, GOST3410Params {
   private GOST3410PublicKeyParameterSetSpec keyParameters;
   private String keyParamSetOID;
   private String digestParamSetOID;
   private String encryptionParamSetOID;

   public GOST3410ParameterSpec(String keyParamSetID, String digestParamSetOID, String encryptionParamSetOID) {
      GOST3410ParamSetParameters var4 = null;

      label21: {
         GOST3410ParamSetParameters var10000;
         try {
            var10000 = GOST3410NamedParameters.getByOID(new DERObjectIdentifier(keyParamSetID));
         } catch (IllegalArgumentException var7) {
            DERObjectIdentifier var5;
            if ((var5 = GOST3410NamedParameters.getOID(keyParamSetID)) != null) {
               keyParamSetID = var5.getId();
               var4 = GOST3410NamedParameters.getByOID(var5);
            }
            break label21;
         }

         var4 = var10000;
      }

      if (var4 != null) {
         GOST3410ParameterSpec var11 = this;
         GOST3410ParameterSpec var10001 = this;
         GOST3410ParameterSpec var10002 = this;
         GOST3410ParameterSpec var10003 = this;
         GOST3410PublicKeyParameterSetSpec var8;
         GOST3410PublicKeyParameterSetSpec var10004 = var8 = new GOST3410PublicKeyParameterSetSpec;
         GOST3410ParamSetParameters var10005 = var4;
         GOST3410ParamSetParameters var10006 = var4;
         BigInteger var9 = var4.getP();
         BigInteger var10 = var10006.getQ();
         BigInteger var6 = var10005.getA();
         var10004.<init>(var9, var10, var6);
         var10003.keyParameters = var8;
         var10002.keyParamSetOID = keyParamSetID;
         var10001.digestParamSetOID = digestParamSetOID;
         var11.encryptionParamSetOID = encryptionParamSetOID;
      } else {
         throw new IllegalArgumentException("no key parameter set for passed in name/OID.");
      }
   }

   public GOST3410ParameterSpec(String keyParamSetID, String digestParamSetOID) {
      this(keyParamSetID, digestParamSetOID, (String)null);
   }

   public GOST3410ParameterSpec(String keyParamSetID) {
      this(keyParamSetID, CryptoProObjectIdentifiers.gostR3411_94_CryptoProParamSet.getId(), (String)null);
   }

   public GOST3410ParameterSpec(GOST3410PublicKeyParameterSetSpec spec) {
      this.keyParameters = spec;
      this.digestParamSetOID = CryptoProObjectIdentifiers.gostR3411_94_CryptoProParamSet.getId();
      this.encryptionParamSetOID = null;
   }

   public static GOST3410ParameterSpec fromPublicKeyAlg(GOST3410PublicKeyAlgParameters params) {
      if (params.getEncryptionParamSet() != null) {
         String var10002 = params.getPublicKeyParamSet().getId();
         GOST3410PublicKeyAlgParameters var10003 = params;
         String params1 = params.getDigestParamSet().getId();
         return new GOST3410ParameterSpec(var10002, params1, var10003.getEncryptionParamSet().getId());
      } else {
         return new GOST3410ParameterSpec(params.getPublicKeyParamSet().getId(), params.getDigestParamSet().getId());
      }
   }

   public String getPublicKeyParamSetOID() {
      return this.keyParamSetOID;
   }

   public GOST3410PublicKeyParameterSetSpec getPublicKeyParameters() {
      return this.keyParameters;
   }

   public String getDigestParamSetOID() {
      return this.digestParamSetOID;
   }

   public String getEncryptionParamSetOID() {
      return this.encryptionParamSetOID;
   }

   public boolean equals(Object o) {
      if (!(o instanceof GOST3410ParameterSpec)) {
         return false;
      } else {
         GOST3410ParameterSpec o1 = (GOST3410ParameterSpec)o;
         String var2;
         String o2;
         return this.keyParameters.equals(o1.keyParameters) && this.digestParamSetOID.equals(o1.digestParamSetOID) && ((var2 = this.encryptionParamSetOID) == (o2 = o1.encryptionParamSetOID) || var2 != null && var2.equals(o2));
      }
   }

   public int hashCode() {
      GOST3410ParameterSpec var10000 = this;
      int var2 = this.keyParameters.hashCode() ^ this.digestParamSetOID.hashCode();
      String var1;
      int var3;
      if ((var1 = var10000.encryptionParamSetOID) != null) {
         var3 = var1.hashCode();
      } else {
         var3 = 0;
      }

      return var2 ^ var3;
   }
}
